@@ -2,8 +2,9 @@ package Acme::Ford::Prefect::FFI;
 
 use strict;
 use warnings;
+use 5.008001;
 use Acme::Alien::DontPanic;
-use FFI::Raw;
+use FFI::Platypus::Declare;
 
 =head1 NAME
 
@@ -27,7 +28,7 @@ L<Acme::Alien::DontPanic> which provides the needed libdontpanic library to be a
 
 =over 4
 
-=item L<FFI::Raw>
+=item L<FFI::Platypus>
 
 =item L<Alien::Base>
 
@@ -37,17 +38,13 @@ L<Acme::Alien::DontPanic> which provides the needed libdontpanic library to be a
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 $VERSION = eval $VERSION;
 
 our($dll) = Acme::Alien::DontPanic->dynamic_libs;
 die "no dll found for libdontpanic" unless $dll;
+lib $dll;
 
-our $answer = FFI::Raw->new(
-  $dll, 'answer',
-  FFI::Raw::int,
-);
-
-sub answer { $answer->() }
+attach answer => [] => int => '';
 
 1;
